Documentation
¶
Index ¶
- Constants
- Variables
- type ForwardingRules
- func (*ForwardingRules) Descriptor() ([]byte, []int)deprecated
- func (x *ForwardingRules) GetReEvalSec() int32
- func (x *ForwardingRules) GetRegionFilter() string
- func (*ForwardingRules) ProtoMessage()
- func (x *ForwardingRules) ProtoReflect() protoreflect.Message
- func (x *ForwardingRules) Reset()
- func (x *ForwardingRules) String() string
- type GCEInstances
- func (*GCEInstances) Descriptor() ([]byte, []int)deprecated
- func (x *GCEInstances) GetReEvalSec() int32
- func (x *GCEInstances) GetZoneFilter() string
- func (*GCEInstances) ProtoMessage()
- func (x *GCEInstances) ProtoReflect() protoreflect.Message
- func (x *GCEInstances) Reset()
- func (x *GCEInstances) String() string
- type ProviderConfig
- func (*ProviderConfig) Descriptor() ([]byte, []int)deprecated
- func (x *ProviderConfig) GetApiEndpoint() string
- func (x *ProviderConfig) GetApiVersion() string
- func (x *ProviderConfig) GetForwardingRules() *ForwardingRules
- func (x *ProviderConfig) GetGceInstances() *GCEInstances
- func (x *ProviderConfig) GetProject() []string
- func (x *ProviderConfig) GetPubsubMessages() *PubSubMessages
- func (x *ProviderConfig) GetRtcVariables() *RTCVariables
- func (*ProviderConfig) ProtoMessage()
- func (x *ProviderConfig) ProtoReflect() protoreflect.Message
- func (x *ProviderConfig) Reset()
- func (x *ProviderConfig) String() string
- type PubSubMessages
- func (*PubSubMessages) Descriptor() ([]byte, []int)deprecated
- func (x *PubSubMessages) GetApiEndpoint() string
- func (x *PubSubMessages) GetSubscription() []*PubSubMessages_Subscription
- func (*PubSubMessages) ProtoMessage()
- func (x *PubSubMessages) ProtoReflect() protoreflect.Message
- func (x *PubSubMessages) Reset()
- func (x *PubSubMessages) String() string
- type PubSubMessages_Subscription
- func (*PubSubMessages_Subscription) Descriptor() ([]byte, []int)deprecated
- func (x *PubSubMessages_Subscription) GetName() string
- func (x *PubSubMessages_Subscription) GetSeekBackDurationSec() int32
- func (x *PubSubMessages_Subscription) GetTopicName() string
- func (*PubSubMessages_Subscription) ProtoMessage()
- func (x *PubSubMessages_Subscription) ProtoReflect() protoreflect.Message
- func (x *PubSubMessages_Subscription) Reset()
- func (x *PubSubMessages_Subscription) String() string
- type RTCVariables
- type RTCVariables_RTCConfig
- func (*RTCVariables_RTCConfig) Descriptor() ([]byte, []int)deprecated
- func (x *RTCVariables_RTCConfig) GetName() string
- func (x *RTCVariables_RTCConfig) GetReEvalSec() int32
- func (*RTCVariables_RTCConfig) ProtoMessage()
- func (x *RTCVariables_RTCConfig) ProtoReflect() protoreflect.Message
- func (x *RTCVariables_RTCConfig) Reset()
- func (x *RTCVariables_RTCConfig) String() string
Constants ¶
const ( Default_ProviderConfig_ApiVersion = string("v1") Default_ProviderConfig_ApiEndpoint = string("https://www.googleapis.com/compute/") )
Default values for ProviderConfig fields.
const (
Default_ForwardingRules_ReEvalSec = int32(300)
)
Default values for ForwardingRules fields.
const (
Default_GCEInstances_ReEvalSec = int32(300)
)
Default values for GCEInstances fields.
const (
Default_PubSubMessages_Subscription_SeekBackDurationSec = int32(3600)
)
Default values for PubSubMessages_Subscription fields.
const (
Default_RTCVariables_RTCConfig_ReEvalSec = int32(10)
)
Default values for RTCVariables_RTCConfig fields.
Variables ¶
var File_github_com_cloudprober_cloudprober_internal_rds_gcp_proto_config_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ForwardingRules ¶
type ForwardingRules struct {
// Optionl region filter regex to limit discovery to specific regions, e.g.
// "region_filter:europe-*"
RegionFilter *string `protobuf:"bytes,1,opt,name=region_filter,json=regionFilter" json:"region_filter,omitempty"`
// How often resources should be refreshed.
ReEvalSec *int32 `protobuf:"varint,98,opt,name=re_eval_sec,json=reEvalSec,def=300" json:"re_eval_sec,omitempty"` // default 5 min
// contains filtered or unexported fields
}
func (*ForwardingRules) Descriptor
deprecated
func (*ForwardingRules) Descriptor() ([]byte, []int)
Deprecated: Use ForwardingRules.ProtoReflect.Descriptor instead.
func (*ForwardingRules) GetReEvalSec ¶
func (x *ForwardingRules) GetReEvalSec() int32
func (*ForwardingRules) GetRegionFilter ¶
func (x *ForwardingRules) GetRegionFilter() string
func (*ForwardingRules) ProtoMessage ¶
func (*ForwardingRules) ProtoMessage()
func (*ForwardingRules) ProtoReflect ¶
func (x *ForwardingRules) ProtoReflect() protoreflect.Message
func (*ForwardingRules) Reset ¶
func (x *ForwardingRules) Reset()
func (*ForwardingRules) String ¶
func (x *ForwardingRules) String() string
type GCEInstances ¶
type GCEInstances struct {
// Optional zone filter regex to limit discovery to the specific zones
// For example, zone_filter: "us-east1-*" will limit instances discovery to
// only to the zones in the "us-east1" region.
ZoneFilter *string `protobuf:"bytes,1,opt,name=zone_filter,json=zoneFilter" json:"zone_filter,omitempty"`
// How often resources should be refreshed.
ReEvalSec *int32 `protobuf:"varint,98,opt,name=re_eval_sec,json=reEvalSec,def=300" json:"re_eval_sec,omitempty"` // default 5 min
// contains filtered or unexported fields
}
func (*GCEInstances) Descriptor
deprecated
func (*GCEInstances) Descriptor() ([]byte, []int)
Deprecated: Use GCEInstances.ProtoReflect.Descriptor instead.
func (*GCEInstances) GetReEvalSec ¶
func (x *GCEInstances) GetReEvalSec() int32
func (*GCEInstances) GetZoneFilter ¶
func (x *GCEInstances) GetZoneFilter() string
func (*GCEInstances) ProtoMessage ¶
func (*GCEInstances) ProtoMessage()
func (*GCEInstances) ProtoReflect ¶
func (x *GCEInstances) ProtoReflect() protoreflect.Message
func (*GCEInstances) Reset ¶
func (x *GCEInstances) Reset()
func (*GCEInstances) String ¶
func (x *GCEInstances) String() string
type ProviderConfig ¶
type ProviderConfig struct {
// GCP projects. If running on GCE, it defaults to the local project.
Project []string `protobuf:"bytes,1,rep,name=project" json:"project,omitempty"`
// GCE instances discovery options. This field should be declared for the GCE
// instances discovery to be enabled.
GceInstances *GCEInstances `protobuf:"bytes,2,opt,name=gce_instances,json=gceInstances" json:"gce_instances,omitempty"`
// Forwarding rules discovery options. This field should be declared for the
// forwarding rules discovery to be enabled.
// Note that RDS supports only regional forwarding rules.
ForwardingRules *ForwardingRules `protobuf:"bytes,3,opt,name=forwarding_rules,json=forwardingRules" json:"forwarding_rules,omitempty"`
// RTC variables discovery options.
RtcVariables *RTCVariables `protobuf:"bytes,4,opt,name=rtc_variables,json=rtcVariables" json:"rtc_variables,omitempty"`
// PubSub messages discovery options.
PubsubMessages *PubSubMessages `protobuf:"bytes,5,opt,name=pubsub_messages,json=pubsubMessages" json:"pubsub_messages,omitempty"`
// Compute API version.
ApiVersion *string `protobuf:"bytes,99,opt,name=api_version,json=apiVersion,def=v1" json:"api_version,omitempty"`
// Compute API endpoint. Currently supported only for GCE instances and
// forwarding rules.
ApiEndpoint *string `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
GCP provider config.
func (*ProviderConfig) Descriptor
deprecated
func (*ProviderConfig) Descriptor() ([]byte, []int)
Deprecated: Use ProviderConfig.ProtoReflect.Descriptor instead.
func (*ProviderConfig) GetApiEndpoint ¶
func (x *ProviderConfig) GetApiEndpoint() string
func (*ProviderConfig) GetApiVersion ¶
func (x *ProviderConfig) GetApiVersion() string
func (*ProviderConfig) GetForwardingRules ¶
func (x *ProviderConfig) GetForwardingRules() *ForwardingRules
func (*ProviderConfig) GetGceInstances ¶
func (x *ProviderConfig) GetGceInstances() *GCEInstances
func (*ProviderConfig) GetProject ¶
func (x *ProviderConfig) GetProject() []string
func (*ProviderConfig) GetPubsubMessages ¶
func (x *ProviderConfig) GetPubsubMessages() *PubSubMessages
func (*ProviderConfig) GetRtcVariables ¶
func (x *ProviderConfig) GetRtcVariables() *RTCVariables
func (*ProviderConfig) ProtoMessage ¶
func (*ProviderConfig) ProtoMessage()
func (*ProviderConfig) ProtoReflect ¶
func (x *ProviderConfig) ProtoReflect() protoreflect.Message
func (*ProviderConfig) Reset ¶
func (x *ProviderConfig) Reset()
func (*ProviderConfig) String ¶
func (x *ProviderConfig) String() string
type PubSubMessages ¶
type PubSubMessages struct {
Subscription []*PubSubMessages_Subscription `protobuf:"bytes,1,rep,name=subscription" json:"subscription,omitempty"`
// Only for testing.
ApiEndpoint *string `protobuf:"bytes,2,opt,name=api_endpoint,json=apiEndpoint" json:"api_endpoint,omitempty"`
// contains filtered or unexported fields
}
Runtime configurator variables.
func (*PubSubMessages) Descriptor
deprecated
func (*PubSubMessages) Descriptor() ([]byte, []int)
Deprecated: Use PubSubMessages.ProtoReflect.Descriptor instead.
func (*PubSubMessages) GetApiEndpoint ¶
func (x *PubSubMessages) GetApiEndpoint() string
func (*PubSubMessages) GetSubscription ¶
func (x *PubSubMessages) GetSubscription() []*PubSubMessages_Subscription
func (*PubSubMessages) ProtoMessage ¶
func (*PubSubMessages) ProtoMessage()
func (*PubSubMessages) ProtoReflect ¶
func (x *PubSubMessages) ProtoReflect() protoreflect.Message
func (*PubSubMessages) Reset ¶
func (x *PubSubMessages) Reset()
func (*PubSubMessages) String ¶
func (x *PubSubMessages) String() string
type PubSubMessages_Subscription ¶
type PubSubMessages_Subscription struct {
// Subscription name. If it doesn't exist already, we try to create one.
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
// Topic name. This is used to create the subscription if it doesn't exist
// already.
TopicName *string `protobuf:"bytes,2,opt,name=topic_name,json=topicName" json:"topic_name,omitempty"`
// If subscription already exists, how far back to seek back on restart.
// Note that duplicate data is fine as we filter by publish time.
SeekBackDurationSec *int32 `protobuf:"varint,3,opt,name=seek_back_duration_sec,json=seekBackDurationSec,def=3600" json:"seek_back_duration_sec,omitempty"`
// contains filtered or unexported fields
}
func (*PubSubMessages_Subscription) Descriptor
deprecated
func (*PubSubMessages_Subscription) Descriptor() ([]byte, []int)
Deprecated: Use PubSubMessages_Subscription.ProtoReflect.Descriptor instead.
func (*PubSubMessages_Subscription) GetName ¶
func (x *PubSubMessages_Subscription) GetName() string
func (*PubSubMessages_Subscription) GetSeekBackDurationSec ¶
func (x *PubSubMessages_Subscription) GetSeekBackDurationSec() int32
func (*PubSubMessages_Subscription) GetTopicName ¶
func (x *PubSubMessages_Subscription) GetTopicName() string
func (*PubSubMessages_Subscription) ProtoMessage ¶
func (*PubSubMessages_Subscription) ProtoMessage()
func (*PubSubMessages_Subscription) ProtoReflect ¶
func (x *PubSubMessages_Subscription) ProtoReflect() protoreflect.Message
func (*PubSubMessages_Subscription) Reset ¶
func (x *PubSubMessages_Subscription) Reset()
func (*PubSubMessages_Subscription) String ¶
func (x *PubSubMessages_Subscription) String() string
type RTCVariables ¶
type RTCVariables struct {
RtcConfig []*RTCVariables_RTCConfig `protobuf:"bytes,1,rep,name=rtc_config,json=rtcConfig" json:"rtc_config,omitempty"`
// contains filtered or unexported fields
}
Runtime configurator variables.
func (*RTCVariables) Descriptor
deprecated
func (*RTCVariables) Descriptor() ([]byte, []int)
Deprecated: Use RTCVariables.ProtoReflect.Descriptor instead.
func (*RTCVariables) GetRtcConfig ¶
func (x *RTCVariables) GetRtcConfig() []*RTCVariables_RTCConfig
func (*RTCVariables) ProtoMessage ¶
func (*RTCVariables) ProtoMessage()
func (*RTCVariables) ProtoReflect ¶
func (x *RTCVariables) ProtoReflect() protoreflect.Message
func (*RTCVariables) Reset ¶
func (x *RTCVariables) Reset()
func (*RTCVariables) String ¶
func (x *RTCVariables) String() string
type RTCVariables_RTCConfig ¶
type RTCVariables_RTCConfig struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
// How often RTC variables should be evaluated/expanded.
ReEvalSec *int32 `protobuf:"varint,2,opt,name=re_eval_sec,json=reEvalSec,def=10" json:"re_eval_sec,omitempty"` // default 10 sec
// contains filtered or unexported fields
}
func (*RTCVariables_RTCConfig) Descriptor
deprecated
func (*RTCVariables_RTCConfig) Descriptor() ([]byte, []int)
Deprecated: Use RTCVariables_RTCConfig.ProtoReflect.Descriptor instead.
func (*RTCVariables_RTCConfig) GetName ¶
func (x *RTCVariables_RTCConfig) GetName() string
func (*RTCVariables_RTCConfig) GetReEvalSec ¶
func (x *RTCVariables_RTCConfig) GetReEvalSec() int32
func (*RTCVariables_RTCConfig) ProtoMessage ¶
func (*RTCVariables_RTCConfig) ProtoMessage()
func (*RTCVariables_RTCConfig) ProtoReflect ¶
func (x *RTCVariables_RTCConfig) ProtoReflect() protoreflect.Message
func (*RTCVariables_RTCConfig) Reset ¶
func (x *RTCVariables_RTCConfig) Reset()
func (*RTCVariables_RTCConfig) String ¶
func (x *RTCVariables_RTCConfig) String() string