Documentation
¶
Overview ¶
Package prober provides a prober for running a set of probes.
Prober takes in a config proto which dictates what probes should be created with what configuration, and manages the asynchronous fan-in/fan-out of the metrics data from these probes.
Index ¶
- type Prober
- func (pr *Prober) AddProbe(ctx context.Context, req *pb.AddProbeRequest) (*pb.AddProbeResponse, error)
- func (pr *Prober) ListProbes(ctx context.Context, req *pb.ListProbesRequest) (*pb.ListProbesResponse, error)
- func (pr *Prober) RemoveProbe(ctx context.Context, req *pb.RemoveProbeRequest) (*pb.RemoveProbeResponse, error)
- func (pr *Prober) Run(ctx context.Context, probeNames []string) (map[string][]*singlerun.ProbeRunResult, error)
- func (pr *Prober) RunProbe(ctx context.Context, req *pb.RunProbeRequest) (*pb.RunProbeResponse, error)
- func (pr *Prober) SaveProbesConfig(ctx context.Context, req *pb.SaveProbesConfigRequest) (*pb.SaveProbesConfigResponse, error)
- func (pr *Prober) Start(ctx context.Context)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Prober ¶
type Prober struct {
Probes map[string]*probes.ProbeInfo
Servers []*servers.ServerInfo
Surfacers []*surfacers.SurfacerInfo
// Required for all gRPC server implementations.
spb.UnimplementedCloudproberServer
// contains filtered or unexported fields
}
Prober represents a collection of probes where each probe implements the Probe interface.
func (*Prober) AddProbe ¶
func (pr *Prober) AddProbe(ctx context.Context, req *pb.AddProbeRequest) (*pb.AddProbeResponse, error)
AddProbe adds the given probe to cloudprober.
func (*Prober) ListProbes ¶
func (pr *Prober) ListProbes(ctx context.Context, req *pb.ListProbesRequest) (*pb.ListProbesResponse, error)
ListProbes gRPC method returns the list of probes from the in-memory database.
func (*Prober) RemoveProbe ¶
func (pr *Prober) RemoveProbe(ctx context.Context, req *pb.RemoveProbeRequest) (*pb.RemoveProbeResponse, error)
RemoveProbe gRPC method cancels the given probe and removes its from the prober's internal database.
func (*Prober) Run ¶ added in v0.14.1
func (pr *Prober) Run(ctx context.Context, probeNames []string) (map[string][]*singlerun.ProbeRunResult, error)
Run runs requested 'probeNames' once.
func (*Prober) RunProbe ¶ added in v0.14.2
func (pr *Prober) RunProbe(ctx context.Context, req *pb.RunProbeRequest) (*pb.RunProbeResponse, error)
func (*Prober) SaveProbesConfig ¶ added in v0.13.3
func (pr *Prober) SaveProbesConfig(ctx context.Context, req *pb.SaveProbesConfigRequest) (*pb.SaveProbesConfigResponse, error)
Click to show internal directories.
Click to hide internal directories.